@@ -63,7 +63,7 @@
 
 /* Note: in x86_64 computers, there's hardly any speed up from having > 2
    threads zeroing out an array */
-void set_to_zero(real_t *arr, size_t n, int_t nthreads)
+void set_to_zero_(real_t *arr, size_t n, int_t nthreads)
 {
     if (n == 0) return;
     #if defined(_OPENMP)
@@ -88,7 +88,7 @@ void set_to_zero(real_t *arr, size_t n, int_t nthreads)
 
 /* Note: in x86_64 computers, there's hardly any speed up from having > 4
    threads copying arrays */
-void copy_arr(real_t *restrict src, real_t *restrict dest, size_t n, int_t nthreads)
+void copy_arr_(real_t *restrict src, real_t *restrict dest, size_t n, int_t nthreads)
 {
     /* Note: don't use BLAS scopy as it's actually much slower */
     if (n == 0) return;
@@ -727,12 +727,12 @@ void sum_mat
     real_t *restrict B, size_t ldb
 )
 {
-    int_t n_int_t = (int)n;
-    if (lda == n && ldb == n)
-        taxpy_large(A, 1., B, m*n, 1);
-    else
-        for (size_t row = 0; row < m; row++)
-            cblas_taxpy(n_int_t, 1., A + row*lda, 1, B + row*ldb, 1);
+    /* Note1: do NOT change this to axpy, it gets a huge slow-down when
+       used with MKL for some reason. OpenBLAS still works fine though */
+    /* Note2: in most cases it is expected that m >> n */
+    for (size_t row = 0; row < m; row++)
+        for (size_t col = 0; col < n; col++)
+            B[col + row*ldb] += A[col + row*lda];
 }
 
 void transpose_mat(real_t *restrict A, size_t m, size_t n, real_t *restrict buffer_real_t)
@@ -976,7 +976,7 @@ void row_means_csr(size_t indptr[], real_t *restrict values,
                    real_t *restrict output, int_t m, int_t nthreads)
 {
     int_t row = 0;
-    set_to_zero(values, m, nthreads);
+    set_to_zero(values, m);
     #pragma omp parallel for schedule(dynamic) num_threads(nthreads) \
             shared(indptr, values, output, m)
     for (row = 0; row < m; row++)
@@ -1016,7 +1016,7 @@ int_t lbfgs_printer_collective
     ((data_collective_fun_grad*)instance)->niter = k;
     int_t print_every = ((data_collective_fun_grad*)instance)->print_every;
     if ((k % print_every) == 0 && print_every > 0) {
-        printf("Iteration %3d - f(x)=%7.03g - ||g(x)||=%5.03g - ls=%d\n",
+        printf("Iteration %-4d - f(x)= %-8.03g - ||g(x)||= %-8.03g - ls=% 2d\n",
                k, fx, gnorm, ls);
         #if !defined(_FOR_R)
         fflush(stdout);
@@ -1048,7 +1048,7 @@ int_t lbfgs_printer_offsets
     ((data_offsets_fun_grad*)instance)->niter = k;
     int_t print_every = ((data_offsets_fun_grad*)instance)->print_every;
     if ((k % print_every) == 0 && print_every > 0) {
-        printf("Iteration %3d - f(x)=%7.03g - ||g(x)||=%5.03g - ls=%d\n",
+        printf("Iteration %-4d - f(x)= %-8.03g - ||g(x)||= %-8.03g - ls=% 2d\n",
                k, fx, gnorm, ls);
         #if !defined(_FOR_R)
         fflush(stdout);
